"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (interests)
"""

import abc
import collections.abc
import grpc
import grpc.aio
import iotics.api.interest_pb2
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class InterestAPIStub:
    """---------------------------------------------------------------------------------------------------------------------

    InterestAPI enables creation and management of interests between a twin and a feed or an input.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    FetchInterests: grpc.UnaryStreamMultiCallable[
        iotics.api.interest_pb2.FetchInterestRequest,
        iotics.api.interest_pb2.FetchInterestResponse,
    ]
    """Fetch feed data for this interest. (local and remote)"""

    FetchLastStored: grpc.UnaryUnaryMultiCallable[
        iotics.api.interest_pb2.FetchLastStoredRequest,
        iotics.api.interest_pb2.FetchInterestResponse,
    ]
    """Fetch last data shared on this interest. (local and remote)"""

    SendInputMessage: grpc.UnaryUnaryMultiCallable[
        iotics.api.interest_pb2.SendInputMessageRequest,
        iotics.api.interest_pb2.SendInputMessageResponse,
    ]
    """Send a message to an input. (local and remote)"""

class InterestAPIAsyncStub:
    """---------------------------------------------------------------------------------------------------------------------

    InterestAPI enables creation and management of interests between a twin and a feed or an input.
    """

    FetchInterests: grpc.aio.UnaryStreamMultiCallable[
        iotics.api.interest_pb2.FetchInterestRequest,
        iotics.api.interest_pb2.FetchInterestResponse,
    ]
    """Fetch feed data for this interest. (local and remote)"""

    FetchLastStored: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.interest_pb2.FetchLastStoredRequest,
        iotics.api.interest_pb2.FetchInterestResponse,
    ]
    """Fetch last data shared on this interest. (local and remote)"""

    SendInputMessage: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.interest_pb2.SendInputMessageRequest,
        iotics.api.interest_pb2.SendInputMessageResponse,
    ]
    """Send a message to an input. (local and remote)"""

class InterestAPIServicer(metaclass=abc.ABCMeta):
    """---------------------------------------------------------------------------------------------------------------------

    InterestAPI enables creation and management of interests between a twin and a feed or an input.
    """

    @abc.abstractmethod
    def FetchInterests(
        self,
        request: iotics.api.interest_pb2.FetchInterestRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[iotics.api.interest_pb2.FetchInterestResponse], collections.abc.AsyncIterator[iotics.api.interest_pb2.FetchInterestResponse]]:
        """Fetch feed data for this interest. (local and remote)"""

    @abc.abstractmethod
    def FetchLastStored(
        self,
        request: iotics.api.interest_pb2.FetchLastStoredRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.interest_pb2.FetchInterestResponse, collections.abc.Awaitable[iotics.api.interest_pb2.FetchInterestResponse]]:
        """Fetch last data shared on this interest. (local and remote)"""

    @abc.abstractmethod
    def SendInputMessage(
        self,
        request: iotics.api.interest_pb2.SendInputMessageRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.interest_pb2.SendInputMessageResponse, collections.abc.Awaitable[iotics.api.interest_pb2.SendInputMessageResponse]]:
        """Send a message to an input. (local and remote)"""

def add_InterestAPIServicer_to_server(servicer: InterestAPIServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (interests)
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import iotics.api.common_pb2
import iotics.api.feed_pb2
import iotics.api.input_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InputInterest(google.protobuf.message.Message):
    """An interest is the relationship between a Twin and an Input."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDERTWINID_FIELD_NUMBER: builtins.int
    DESTINPUTID_FIELD_NUMBER: builtins.int
    @property
    def senderTwinId(self) -> iotics.api.common_pb2.TwinID:
        """Sender twin unique identifier."""

    @property
    def destInputId(self) -> iotics.api.input_pb2.InputID:
        """a reference to the input of interest"""

    def __init__(
        self,
        *,
        senderTwinId: iotics.api.common_pb2.TwinID | None = ...,
        destInputId: iotics.api.input_pb2.InputID | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destInputId", b"destInputId", "senderTwinId", b"senderTwinId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destInputId", b"destInputId", "senderTwinId", b"senderTwinId"]) -> None: ...

global___InputInterest = InputInterest

@typing.final
class SendInputMessageRequest(google.protobuf.message.Message):
    """SendInputMessageRequest is used to send a message to a given input."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """SendInputMessageRequest payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MESSAGE_FIELD_NUMBER: builtins.int
        @property
        def message(self) -> iotics.api.input_pb2.InputMessage:
            """Message to send"""

        def __init__(
            self,
            *,
            message: iotics.api.input_pb2.InputMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["message", b"message"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["message", b"message"]) -> None: ...

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """SendInputMessageRequest arguments."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INTEREST_FIELD_NUMBER: builtins.int
        @property
        def interest(self) -> global___InputInterest:
            """The interest"""

        def __init__(
            self,
            *,
            interest: global___InputInterest | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["interest", b"interest"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["interest", b"interest"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """SendInputMessageRequest headers"""

    @property
    def args(self) -> global___SendInputMessageRequest.Arguments:
        """SendInputMessageRequest mandatory arguments"""

    @property
    def payload(self) -> global___SendInputMessageRequest.Payload:
        """SendInputMessageRequest payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___SendInputMessageRequest.Arguments | None = ...,
        payload: global___SendInputMessageRequest.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers", "payload", b"payload"]) -> None: ...

global___SendInputMessageRequest = SendInputMessageRequest

@typing.final
class SendInputMessageResponse(google.protobuf.message.Message):
    """SendInputMessageResponse is used to indicate a successful send."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADERS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """SendInputMessageResponse headers"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers"]) -> None: ...

global___SendInputMessageResponse = SendInputMessageResponse

@typing.final
class Interest(google.protobuf.message.Message):
    """An interest is the relationship between a Twin and a Feed. For example, creating
    an interest on (following) a Feed results in any data shared on said Feed to be forwarded to
    the associated Twin. Interests can be revoked either by the subscriber or provider and there
    may only be one interest between any unique Twin and Feed combination.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLLOWERTWINID_FIELD_NUMBER: builtins.int
    FOLLOWEDFEEDID_FIELD_NUMBER: builtins.int
    @property
    def followerTwinId(self) -> iotics.api.common_pb2.TwinID:
        """Follower twin unique identifier."""

    @property
    def followedFeedId(self) -> iotics.api.feed_pb2.FeedID:
        """a reference to the interested feed"""

    def __init__(
        self,
        *,
        followerTwinId: iotics.api.common_pb2.TwinID | None = ...,
        followedFeedId: iotics.api.feed_pb2.FeedID | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["followedFeedId", b"followedFeedId", "followerTwinId", b"followerTwinId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["followedFeedId", b"followedFeedId", "followerTwinId", b"followerTwinId"]) -> None: ...

global___Interest = Interest

@typing.final
class FetchInterestRequest(google.protobuf.message.Message):
    """---------------------------------------

    FetchInterestRequest is used to initiate a stream to get the feed data shared on a given interest.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """FetchInterestRequest mandatory arguments."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INTEREST_FIELD_NUMBER: builtins.int
        @property
        def interest(self) -> global___Interest:
            """The interest"""

        def __init__(
            self,
            *,
            interest: global___Interest | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["interest", b"interest"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["interest", b"interest"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    FETCHLASTSTORED_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """FetchInterestRequest headers"""

    @property
    def args(self) -> global___FetchInterestRequest.Arguments:
        """FetchInterestRequest arguments"""

    @property
    def fetchLastStored(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """whether to fetch the last stored value if available (false by default)"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___FetchInterestRequest.Arguments | None = ...,
        fetchLastStored: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "fetchLastStored", b"fetchLastStored", "headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "fetchLastStored", b"fetchLastStored", "headers", b"headers"]) -> None: ...

global___FetchInterestRequest = FetchInterestRequest

@typing.final
class FetchInterestResponse(google.protobuf.message.Message):
    """FetchInterestResponse describes a feed value shared on a given interest."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """FetchInterestResponse payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INTEREST_FIELD_NUMBER: builtins.int
        FEEDDATA_FIELD_NUMBER: builtins.int
        @property
        def interest(self) -> global___Interest:
            """The interest"""

        @property
        def feedData(self) -> iotics.api.common_pb2.FeedData:
            """The shared data"""

        def __init__(
            self,
            *,
            interest: global___Interest | None = ...,
            feedData: iotics.api.common_pb2.FeedData | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["feedData", b"feedData", "interest", b"interest"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["feedData", b"feedData", "interest", b"interest"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """FetchInterestResponse headers"""

    @property
    def payload(self) -> global___FetchInterestResponse.Payload:
        """FetchInterestResponse payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___FetchInterestResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___FetchInterestResponse = FetchInterestResponse

@typing.final
class FetchLastStoredRequest(google.protobuf.message.Message):
    """---------------------------------------

    FetchLastStoredRequest is used to fetch the last stored value on a given interest if available.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Arguments(google.protobuf.message.Message):
        """FetchLastStoredRequest mandatory arguments."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INTEREST_FIELD_NUMBER: builtins.int
        @property
        def interest(self) -> global___Interest:
            """The interest"""

        def __init__(
            self,
            *,
            interest: global___Interest | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["interest", b"interest"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["interest", b"interest"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """FetchLastStoredRequest headers"""

    @property
    def args(self) -> global___FetchLastStoredRequest.Arguments:
        """FetchLastStoredRequest arguments"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___FetchLastStoredRequest.Arguments | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> None: ...

global___FetchLastStoredRequest = FetchLastStoredRequest



# Copyright © 2022 IOTIC LABS LTD. info@iotics.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://github.com/Iotic-Labs/iotics-grpc-client-py/blob/main/LICENSE
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import typing

import grpc

from iotics.lib.grpc.auth import AuthInterface
from iotics.lib.grpc.base import ApiBase
from iotics.lib.grpc.feeds import FeedApi
from iotics.lib.grpc.helpers import get_channel
from iotics.lib.grpc.input import InputApi
from iotics.lib.grpc.interest import InterestApi
from iotics.lib.grpc.search import SearchApi
from iotics.lib.grpc.sparql import SparqlApi
from iotics.lib.grpc.twins import TwinApi
from iotics.lib.grpc.circles import CircleAPI
from iotics.lib.grpc.host import HostApi


class IoticsApi:
    def __init__(self, auth, channel=None):
        self._auth: AuthInterface = auth
        self._channel: typing.Optional[grpc.Channel] = channel
        self._twin_api: typing.Optional[TwinApi] = None
        self._circle_api: typing.Optional[CircleAPI] = None
        self._feed_api: typing.Optional[FeedApi] = None
        self._input_api: typing.Optional[InputApi] = None
        self._search_api: typing.Optional[SearchApi] = None
        self._interest_api: typing.Optional[InterestApi] = None
        self._sparql_api: typing.Optional[SparqlApi] = None
        self._host_api: typing.Optional[HostApi] = None
        self._local_host_id: str = None

        self._initialise_twin_api()
        self._initialise_circle_api()
        self._initialise_feed_api()
        self._initialise_input_api()
        self._initialise_interest_api()
        self._initialise_search_api()
        self._initialise_sparql_api()
        self._initialise_host_api()

    @property
    def auth(self) -> AuthInterface:
        return self._auth

    @property
    def channel(self) -> grpc.Channel:
        if not self._channel:
            self._channel = get_channel(self._auth)
        return self._channel

    @property
    def twin_api(self) -> TwinApi:
        if not self._twin_api:
            self._initialise_twin_api()
        return self._twin_api

    @property
    def circle_api(self) -> CircleAPI:
        if not self._circle_api:
            self._initialise_circle_api()
        return self._circle_api

    @property
    def feed_api(self) -> FeedApi:
        if not self._feed_api:
            self._initialise_feed_api()
        return self._feed_api

    @property
    def input_api(self) -> InputApi:
        if not self._input_api:
            self._initialise_input_api()
        return self._input_api

    @property
    def interest_api(self) -> InterestApi:
        if not self._interest_api:
            self._initialise_interest_api()
        return self._interest_api

    @property
    def search_api(self) -> SearchApi:
        if not self._search_api:
            self._initialise_search_api()
        return self._search_api

    @property
    def sparql_api(self) -> SparqlApi:
        if not self._sparql_api:
            self._initialise_sparql_api()
        return self._sparql_api

    @property
    def host_api(self) -> HostApi:
        if not self._host_api:
            self._initialise_host_api()
        return self._host_api

    def update_auth(self, auth, channel=None):
        self._auth = auth
        self.update_channel(channel)

    def update_channel(self, channel: typing.Optional[grpc.Channel] = None):
        self._channel = channel or get_channel(self._auth)
        for api in self._apis():
            if api:
                self._update_api(api)

    def _update_api(self, api: ApiBase):
        if isinstance(api, TwinApi):
            self._initialise_twin_api()
        if isinstance(api, CircleAPI):
            self._initialise_circle_api()
        elif isinstance(api, FeedApi):
            self._initialise_feed_api()
        elif isinstance(api, InputApi):
            self._initialise_input_api()
        elif isinstance(api, InterestApi):
            self._initialise_interest_api()
        elif isinstance(api, SearchApi):
            self._initialise_search_api()
        elif isinstance(api, SparqlApi):
            self._initialise_sparql_api()
        elif isinstance(api, HostApi):
            self._initialise_host_api()

    def _initialise_twin_api(self):
        self._twin_api = TwinApi(self._auth, self._channel)
        self.create_twin = self.twin_api.create_twin
        self.describe_twin = self.twin_api.describe_twin
        self.delete_twin = self.twin_api.delete_twin
        self.list_twins = self.twin_api.list_twins
        self.update_twin = self.twin_api.update_twin
        self.upsert_twin = self.twin_api.upsert_twin

    def _initialise_circle_api(self):
        self._circle_api = CircleAPI(self._auth, self._channel)
        self.upsert_circle = self.circle_api.upsert_circle
        self.describe_circle = self.circle_api.describe_circle
        self.delete_circle = self.circle_api.delete_circle
        self.list_circles = self.circle_api.list_circles

    def _initialise_feed_api(self):
        self._feed_api = FeedApi(self._auth, self._channel)
        self.create_feed = self.feed_api.create_feed
        self.delete_feed = self.feed_api.delete_feed
        self.update_feed = self.feed_api.update_feed
        self.share_feed_data = self.feed_api.share_feed_data
        self.list_all_feeds = self.feed_api.list_all_feeds
        self.describe_feed = self.feed_api.describe_feed

    def _initialise_input_api(self):
        self._input_api = InputApi(self._auth, self._channel)
        self.create_input = self.input_api.create_input
        self.update_input = self.input_api.update_input
        self.describe_input = self.input_api.describe_input
        self.delete_input = self.input_api.delete_input
        self.receive_input_messages = self.input_api.receive_input_messages

    def _initialise_interest_api(self):
        self._interest_api = InterestApi(self._auth, self._channel)
        self.send_input_message = self.interest_api.send_input_message
        self.fetch_interests = self.interest_api.fetch_interests
        self.fetch_last_stored = self.interest_api.fetch_last_stored

    def _initialise_search_api(self):
        self._search_api = SearchApi(self._auth, self._channel)
        self.get_search_payload = self.search_api.get_search_payload
        self.search_iter = self.search_api.search_iter

    def _initialise_sparql_api(self):
        self._sparql_api = SparqlApi(self._auth, self._channel)
        self.sparql_query = self.sparql_api.sparql_query
        self.sparql_update = self.sparql_api.sparql_update

    def _initialise_host_api(self):
        self._host_api = HostApi(self._auth, self._channel)
        self.get_local_host_id = self.host_api.get_local_host_id

    def _apis(self):
        return [
            self._twin_api,
            self._feed_api,
            self._input_api,
            self._search_api,
            self._interest_api,
            self._sparql_api,
            self._host_api,
            self._circle_api
        ]



# Copyright © 2022 IOTIC LABS LTD. info@iotics.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://github.com/Iotic-Labs/iotics-grpc-client-py/blob/main/LICENSE
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import typing


class AuthInterface:
    """Authenticator for gRPC requests to IOTICSpace."""

    def get_host(self) -> str:
        """Provides a host name of an IOTICSpace.

        Returns: IOTICSpace host name and gRPC port.
        """
        raise NotImplementedError

    def get_token(self, ttl: typing.Optional[int]) -> str:
        """Provides an authentication token for a gRPC requests.
        Once generated, will return the same one until refresh_token is called.

        Returns: Encoded JSON Web Token.
        """
        raise NotImplementedError

    def refresh_token(self, ttl: typing.Optional[int]) -> str:
        """Provides a new authentication token for a gRPC requests.

        Returns: Encoded JSON Web Token.
        """
        raise NotImplementedError



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from iotics.api import interest_pb2 as iotics_dot_api_dot_interest__pb2


class InterestAPIStub(object):
    """---------------------------------------------------------------------------------------------------------------------

    InterestAPI enables creation and management of interests between a twin and a feed or an input.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FetchInterests = channel.unary_stream(
                '/iotics.api.InterestAPI/FetchInterests',
                request_serializer=iotics_dot_api_dot_interest__pb2.FetchInterestRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_interest__pb2.FetchInterestResponse.FromString,
                _registered_method=True)
        self.FetchLastStored = channel.unary_unary(
                '/iotics.api.InterestAPI/FetchLastStored',
                request_serializer=iotics_dot_api_dot_interest__pb2.FetchLastStoredRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_interest__pb2.FetchInterestResponse.FromString,
                _registered_method=True)
        self.SendInputMessage = channel.unary_unary(
                '/iotics.api.InterestAPI/SendInputMessage',
                request_serializer=iotics_dot_api_dot_interest__pb2.SendInputMessageRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_interest__pb2.SendInputMessageResponse.FromString,
                _registered_method=True)


class InterestAPIServicer(object):
    """---------------------------------------------------------------------------------------------------------------------

    InterestAPI enables creation and management of interests between a twin and a feed or an input.
    """

    def FetchInterests(self, request, context):
        """Fetch feed data for this interest. (local and remote)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchLastStored(self, request, context):
        """Fetch last data shared on this interest. (local and remote)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendInputMessage(self, request, context):
        """Send a message to an input. (local and remote)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InterestAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FetchInterests': grpc.unary_stream_rpc_method_handler(
                    servicer.FetchInterests,
                    request_deserializer=iotics_dot_api_dot_interest__pb2.FetchInterestRequest.FromString,
                    response_serializer=iotics_dot_api_dot_interest__pb2.FetchInterestResponse.SerializeToString,
            ),
            'FetchLastStored': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchLastStored,
                    request_deserializer=iotics_dot_api_dot_interest__pb2.FetchLastStoredRequest.FromString,
                    response_serializer=iotics_dot_api_dot_interest__pb2.FetchInterestResponse.SerializeToString,
            ),
            'SendInputMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.SendInputMessage,
                    request_deserializer=iotics_dot_api_dot_interest__pb2.SendInputMessageRequest.FromString,
                    response_serializer=iotics_dot_api_dot_interest__pb2.SendInputMessageResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'iotics.api.InterestAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('iotics.api.InterestAPI', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InterestAPI(object):
    """---------------------------------------------------------------------------------------------------------------------

    InterestAPI enables creation and management of interests between a twin and a feed or an input.
    """

    @staticmethod
    def FetchInterests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/iotics.api.InterestAPI/FetchInterests',
            iotics_dot_api_dot_interest__pb2.FetchInterestRequest.SerializeToString,
            iotics_dot_api_dot_interest__pb2.FetchInterestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FetchLastStored(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.InterestAPI/FetchLastStored',
            iotics_dot_api_dot_interest__pb2.FetchLastStoredRequest.SerializeToString,
            iotics_dot_api_dot_interest__pb2.FetchInterestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendInputMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.InterestAPI/SendInputMessage',
            iotics_dot_api_dot_interest__pb2.SendInputMessageRequest.SerializeToString,
            iotics_dot_api_dot_interest__pb2.SendInputMessageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (hosts)
"""

import abc
import collections.abc
import grpc
import grpc.aio
import iotics.api.host_pb2
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class HostAPIStub:
    """---------------------------------------------------------------------------------------------------------------------

    HostAPI enables management of Iotics host twins.
    Services only affect local resources, unless stated otherwise.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetHostID: grpc.UnaryUnaryMultiCallable[
        iotics.api.host_pb2.GetHostIDRequest,
        iotics.api.host_pb2.GetHostIDResponse,
    ]
    """GetHostID gets the ID of the host twin."""

    IsHostDataAllowed: grpc.UnaryUnaryMultiCallable[
        iotics.api.host_pb2.IsHostDataAllowedRequest,
        iotics.api.host_pb2.IsHostDataAllowedResponse,
    ]
    """IsHostDataAllowed determines whether a remote host is allowed to perform data requests against the given twin.
    An example of a data request is interest.SendInputMessage
    """

    IsHostMetaAllowed: grpc.UnaryUnaryMultiCallable[
        iotics.api.host_pb2.IsHostMetaAllowedRequest,
        iotics.api.host_pb2.IsHostMetaAllowedResponse,
    ]
    """IsHostMetaAllowed determines whether a remote host is allowed to perform meta requests against the given twin.
    An example of a meta(data) request is twin.DescribeTwin
    """

class HostAPIAsyncStub:
    """---------------------------------------------------------------------------------------------------------------------

    HostAPI enables management of Iotics host twins.
    Services only affect local resources, unless stated otherwise.
    """

    GetHostID: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.host_pb2.GetHostIDRequest,
        iotics.api.host_pb2.GetHostIDResponse,
    ]
    """GetHostID gets the ID of the host twin."""

    IsHostDataAllowed: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.host_pb2.IsHostDataAllowedRequest,
        iotics.api.host_pb2.IsHostDataAllowedResponse,
    ]
    """IsHostDataAllowed determines whether a remote host is allowed to perform data requests against the given twin.
    An example of a data request is interest.SendInputMessage
    """

    IsHostMetaAllowed: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.host_pb2.IsHostMetaAllowedRequest,
        iotics.api.host_pb2.IsHostMetaAllowedResponse,
    ]
    """IsHostMetaAllowed determines whether a remote host is allowed to perform meta requests against the given twin.
    An example of a meta(data) request is twin.DescribeTwin
    """

class HostAPIServicer(metaclass=abc.ABCMeta):
    """---------------------------------------------------------------------------------------------------------------------

    HostAPI enables management of Iotics host twins.
    Services only affect local resources, unless stated otherwise.
    """

    @abc.abstractmethod
    def GetHostID(
        self,
        request: iotics.api.host_pb2.GetHostIDRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.host_pb2.GetHostIDResponse, collections.abc.Awaitable[iotics.api.host_pb2.GetHostIDResponse]]:
        """GetHostID gets the ID of the host twin."""

    @abc.abstractmethod
    def IsHostDataAllowed(
        self,
        request: iotics.api.host_pb2.IsHostDataAllowedRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.host_pb2.IsHostDataAllowedResponse, collections.abc.Awaitable[iotics.api.host_pb2.IsHostDataAllowedResponse]]:
        """IsHostDataAllowed determines whether a remote host is allowed to perform data requests against the given twin.
        An example of a data request is interest.SendInputMessage
        """

    @abc.abstractmethod
    def IsHostMetaAllowed(
        self,
        request: iotics.api.host_pb2.IsHostMetaAllowedRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.host_pb2.IsHostMetaAllowedResponse, collections.abc.Awaitable[iotics.api.host_pb2.IsHostMetaAllowedResponse]]:
        """IsHostMetaAllowed determines whether a remote host is allowed to perform meta requests against the given twin.
        An example of a meta(data) request is twin.DescribeTwin
        """

def add_HostAPIServicer_to_server(servicer: HostAPIServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from iotics.api import circle_pb2 as iotics_dot_api_dot_circle__pb2


class CircleAPIStub(object):
    """---------------------------------------------------------------------------------------------------------------------

    CircleAPI enables creation and management of Iotics circles.
    Services only affect local resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpsertCircle = channel.unary_unary(
                '/iotics.api.CircleAPI/UpsertCircle',
                request_serializer=iotics_dot_api_dot_circle__pb2.UpsertCircleRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_circle__pb2.UpsertCircleResponse.FromString,
                _registered_method=True)
        self.DeleteCircle = channel.unary_unary(
                '/iotics.api.CircleAPI/DeleteCircle',
                request_serializer=iotics_dot_api_dot_circle__pb2.DeleteCircleRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_circle__pb2.DeleteCircleResponse.FromString,
                _registered_method=True)
        self.DescribeCircle = channel.unary_unary(
                '/iotics.api.CircleAPI/DescribeCircle',
                request_serializer=iotics_dot_api_dot_circle__pb2.DescribeCircleRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_circle__pb2.DescribeCircleResponse.FromString,
                _registered_method=True)
        self.ListAllCircles = channel.unary_unary(
                '/iotics.api.CircleAPI/ListAllCircles',
                request_serializer=iotics_dot_api_dot_circle__pb2.ListAllCirclesRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_circle__pb2.ListAllCirclesResponse.FromString,
                _registered_method=True)


class CircleAPIServicer(object):
    """---------------------------------------------------------------------------------------------------------------------

    CircleAPI enables creation and management of Iotics circles.
    Services only affect local resources.
    """

    def UpsertCircle(self, request, context):
        """UpsertCircle creates or updates a circle with its metadata.
        The full state is applied (ie. if the operation succeeds the state of the circle will
        be the one described in the payload)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCircle(self, request, context):
        """DeleteCircle deletes a circle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribeCircle(self, request, context):
        """Describes a circle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAllCircles(self, request, context):
        """List all circles.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CircleAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpsertCircle': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertCircle,
                    request_deserializer=iotics_dot_api_dot_circle__pb2.UpsertCircleRequest.FromString,
                    response_serializer=iotics_dot_api_dot_circle__pb2.UpsertCircleResponse.SerializeToString,
            ),
            'DeleteCircle': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCircle,
                    request_deserializer=iotics_dot_api_dot_circle__pb2.DeleteCircleRequest.FromString,
                    response_serializer=iotics_dot_api_dot_circle__pb2.DeleteCircleResponse.SerializeToString,
            ),
            'DescribeCircle': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribeCircle,
                    request_deserializer=iotics_dot_api_dot_circle__pb2.DescribeCircleRequest.FromString,
                    response_serializer=iotics_dot_api_dot_circle__pb2.DescribeCircleResponse.SerializeToString,
            ),
            'ListAllCircles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAllCircles,
                    request_deserializer=iotics_dot_api_dot_circle__pb2.ListAllCirclesRequest.FromString,
                    response_serializer=iotics_dot_api_dot_circle__pb2.ListAllCirclesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'iotics.api.CircleAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('iotics.api.CircleAPI', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CircleAPI(object):
    """---------------------------------------------------------------------------------------------------------------------

    CircleAPI enables creation and management of Iotics circles.
    Services only affect local resources.
    """

    @staticmethod
    def UpsertCircle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.CircleAPI/UpsertCircle',
            iotics_dot_api_dot_circle__pb2.UpsertCircleRequest.SerializeToString,
            iotics_dot_api_dot_circle__pb2.UpsertCircleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteCircle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.CircleAPI/DeleteCircle',
            iotics_dot_api_dot_circle__pb2.DeleteCircleRequest.SerializeToString,
            iotics_dot_api_dot_circle__pb2.DeleteCircleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DescribeCircle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.CircleAPI/DescribeCircle',
            iotics_dot_api_dot_circle__pb2.DescribeCircleRequest.SerializeToString,
            iotics_dot_api_dot_circle__pb2.DescribeCircleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAllCircles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.CircleAPI/ListAllCircles',
            iotics_dot_api_dot_circle__pb2.ListAllCirclesRequest.SerializeToString,
            iotics_dot_api_dot_circle__pb2.ListAllCirclesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/feed.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/feed.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15iotics/api/feed.proto\x12\niotics.api\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17iotics/api/common.proto\"H\n\x06\x46\x65\x65\x64ID\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06twinId\x18\x02 \x01(\tR\x06twinId\x12\x16\n\x06hostId\x18\x03 \x01(\tR\x06hostId\"\x94\x02\n\x11\x43reateFeedRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12;\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\'.iotics.api.CreateFeedRequest.ArgumentsR\x04\x61rgs\x12?\n\x07payload\x18\x03 \x01(\x0b\x32%.iotics.api.CreateFeedRequest.PayloadR\x07payload\x1a\x19\n\x07Payload\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x1a\x37\n\tArguments\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\xbc\x01\n\x12\x43reateFeedResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.CreateFeedResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\"\xb8\x01\n\x11\x44\x65leteFeedRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12;\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\'.iotics.api.DeleteFeedRequest.ArgumentsR\x04\x61rgs\x1a\x37\n\tArguments\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\"\xbc\x01\n\x12\x44\x65leteFeedResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.DeleteFeedResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\"\xa7\x03\n\x11UpdateFeedRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12;\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\'.iotics.api.UpdateFeedRequest.ArgumentsR\x04\x61rgs\x12?\n\x07payload\x18\x03 \x01(\x0b\x32%.iotics.api.UpdateFeedRequest.PayloadR\x07payload\x1a\xab\x01\n\x07Payload\x12\x38\n\tstoreLast\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\tstoreLast\x12*\n\x06values\x18\x03 \x01(\x0b\x32\x12.iotics.api.ValuesR\x06values\x12:\n\nproperties\x18\x06 \x01(\x0b\x32\x1a.iotics.api.PropertyUpdateR\nproperties\x1a\x37\n\tArguments\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\"\xbc\x01\n\x12UpdateFeedResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.UpdateFeedResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\"\xbb\x02\n\x14ShareFeedDataRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12>\n\x04\x61rgs\x18\x02 \x01(\x0b\x32*.iotics.api.ShareFeedDataRequest.ArgumentsR\x04\x61rgs\x12\x42\n\x07payload\x18\x03 \x01(\x0b\x32(.iotics.api.ShareFeedDataRequest.PayloadR\x07payload\x1a\x37\n\x07Payload\x12,\n\x06sample\x18\x01 \x01(\x0b\x32\x14.iotics.api.FeedDataR\x06sample\x1a\x37\n\tArguments\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\"F\n\x15ShareFeedDataResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\"\xe5\x01\n\x13ListAllFeedsRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12=\n\x04\x61rgs\x18\x02 \x01(\x0b\x32).iotics.api.ListAllFeedsRequest.ArgumentsR\x04\x61rgs\x12\'\n\x05range\x18\x03 \x01(\x0b\x32\x11.iotics.api.RangeR\x05range\x1a\x37\n\tArguments\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\xc2\x01\n\x14ListAllFeedsResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x42\n\x07payload\x18\x02 \x01(\x0b\x32(.iotics.api.ListAllFeedsResponse.PayloadR\x07payload\x1a\x37\n\x07Payload\x12,\n\x07\x66\x65\x65\x64Ids\x18\x01 \x03(\x0b\x32\x12.iotics.api.FeedIDR\x07\x66\x65\x65\x64Ids\"\xbc\x01\n\x13\x44\x65scribeFeedRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12=\n\x04\x61rgs\x18\x03 \x01(\x0b\x32).iotics.api.DescribeFeedRequest.ArgumentsR\x04\x61rgs\x1a\x37\n\tArguments\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\"\x93\x03\n\x14\x44\x65scribeFeedResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x42\n\x07payload\x18\x02 \x01(\x0b\x32(.iotics.api.DescribeFeedResponse.PayloadR\x07payload\x1a\x8b\x01\n\nMetaResult\x12)\n\x06values\x18\x02 \x03(\x0b\x32\x11.iotics.api.ValueR\x06values\x12\x1c\n\tstoreLast\x18\x05 \x01(\x08R\tstoreLast\x12\x34\n\nproperties\x18\x06 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x1az\n\x07Payload\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\x12\x43\n\x06result\x18\x02 \x01(\x0b\x32+.iotics.api.DescribeFeedResponse.MetaResultR\x06result\"\xa3\x01\n\x12UpsertFeedWithMeta\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1c\n\tstoreLast\x18\x04 \x01(\x08R\tstoreLast\x12)\n\x06values\x18\x05 \x03(\x0b\x32\x11.iotics.api.ValueR\x06values\x12\x34\n\nproperties\x18\x06 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties2\xd3\x04\n\x07\x46\x65\x65\x64\x41PI\x12M\n\nCreateFeed\x12\x1d.iotics.api.CreateFeedRequest\x1a\x1e.iotics.api.CreateFeedResponse\"\x00\x12M\n\nDeleteFeed\x12\x1d.iotics.api.DeleteFeedRequest\x1a\x1e.iotics.api.DeleteFeedResponse\"\x00\x12M\n\nUpdateFeed\x12\x1d.iotics.api.UpdateFeedRequest\x1a\x1e.iotics.api.UpdateFeedResponse\"\x00\x12V\n\rShareFeedData\x12 .iotics.api.ShareFeedDataRequest\x1a!.iotics.api.ShareFeedDataResponse\"\x00\x12Y\n\x0eStreamFeedData\x12 .iotics.api.ShareFeedDataRequest\x1a!.iotics.api.ShareFeedDataResponse\"\x00(\x01\x12S\n\x0cListAllFeeds\x12\x1f.iotics.api.ListAllFeedsRequest\x1a .iotics.api.ListAllFeedsResponse\"\x00\x12S\n\x0c\x44\x65scribeFeed\x12\x1f.iotics.api.DescribeFeedRequest\x1a .iotics.api.DescribeFeedResponse\"\x00\x42}\n\x0e\x63om.iotics.apiB\tFeedProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.feed_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\tFeedProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_FEEDID']._serialized_start=94
  _globals['_FEEDID']._serialized_end=166
  _globals['_CREATEFEEDREQUEST']._serialized_start=169
  _globals['_CREATEFEEDREQUEST']._serialized_end=445
  _globals['_CREATEFEEDREQUEST_PAYLOAD']._serialized_start=363
  _globals['_CREATEFEEDREQUEST_PAYLOAD']._serialized_end=388
  _globals['_CREATEFEEDREQUEST_ARGUMENTS']._serialized_start=390
  _globals['_CREATEFEEDREQUEST_ARGUMENTS']._serialized_end=445
  _globals['_CREATEFEEDRESPONSE']._serialized_start=448
  _globals['_CREATEFEEDRESPONSE']._serialized_end=636
  _globals['_CREATEFEEDRESPONSE_PAYLOAD']._serialized_start=583
  _globals['_CREATEFEEDRESPONSE_PAYLOAD']._serialized_end=636
  _globals['_DELETEFEEDREQUEST']._serialized_start=639
  _globals['_DELETEFEEDREQUEST']._serialized_end=823
  _globals['_DELETEFEEDREQUEST_ARGUMENTS']._serialized_start=768
  _globals['_DELETEFEEDREQUEST_ARGUMENTS']._serialized_end=823
  _globals['_DELETEFEEDRESPONSE']._serialized_start=826
  _globals['_DELETEFEEDRESPONSE']._serialized_end=1014
  _globals['_DELETEFEEDRESPONSE_PAYLOAD']._serialized_start=583
  _globals['_DELETEFEEDRESPONSE_PAYLOAD']._serialized_end=636
  _globals['_UPDATEFEEDREQUEST']._serialized_start=1017
  _globals['_UPDATEFEEDREQUEST']._serialized_end=1440
  _globals['_UPDATEFEEDREQUEST_PAYLOAD']._serialized_start=1212
  _globals['_UPDATEFEEDREQUEST_PAYLOAD']._serialized_end=1383
  _globals['_UPDATEFEEDREQUEST_ARGUMENTS']._serialized_start=768
  _globals['_UPDATEFEEDREQUEST_ARGUMENTS']._serialized_end=823
  _globals['_UPDATEFEEDRESPONSE']._serialized_start=1443
  _globals['_UPDATEFEEDRESPONSE']._serialized_end=1631
  _globals['_UPDATEFEEDRESPONSE_PAYLOAD']._serialized_start=583
  _globals['_UPDATEFEEDRESPONSE_PAYLOAD']._serialized_end=636
  _globals['_SHAREFEEDDATAREQUEST']._serialized_start=1634
  _globals['_SHAREFEEDDATAREQUEST']._serialized_end=1949
  _globals['_SHAREFEEDDATAREQUEST_PAYLOAD']._serialized_start=1837
  _globals['_SHAREFEEDDATAREQUEST_PAYLOAD']._serialized_end=1892
  _globals['_SHAREFEEDDATAREQUEST_ARGUMENTS']._serialized_start=768
  _globals['_SHAREFEEDDATAREQUEST_ARGUMENTS']._serialized_end=823
  _globals['_SHAREFEEDDATARESPONSE']._serialized_start=1951
  _globals['_SHAREFEEDDATARESPONSE']._serialized_end=2021
  _globals['_LISTALLFEEDSREQUEST']._serialized_start=2024
  _globals['_LISTALLFEEDSREQUEST']._serialized_end=2253
  _globals['_LISTALLFEEDSREQUEST_ARGUMENTS']._serialized_start=390
  _globals['_LISTALLFEEDSREQUEST_ARGUMENTS']._serialized_end=445
  _globals['_LISTALLFEEDSRESPONSE']._serialized_start=2256
  _globals['_LISTALLFEEDSRESPONSE']._serialized_end=2450
  _globals['_LISTALLFEEDSRESPONSE_PAYLOAD']._serialized_start=2395
  _globals['_LISTALLFEEDSRESPONSE_PAYLOAD']._serialized_end=2450
  _globals['_DESCRIBEFEEDREQUEST']._serialized_start=2453
  _globals['_DESCRIBEFEEDREQUEST']._serialized_end=2641
  _globals['_DESCRIBEFEEDREQUEST_ARGUMENTS']._serialized_start=768
  _globals['_DESCRIBEFEEDREQUEST_ARGUMENTS']._serialized_end=823
  _globals['_DESCRIBEFEEDRESPONSE']._serialized_start=2644
  _globals['_DESCRIBEFEEDRESPONSE']._serialized_end=3047
  _globals['_DESCRIBEFEEDRESPONSE_METARESULT']._serialized_start=2784
  _globals['_DESCRIBEFEEDRESPONSE_METARESULT']._serialized_end=2923
  _globals['_DESCRIBEFEEDRESPONSE_PAYLOAD']._serialized_start=2925
  _globals['_DESCRIBEFEEDRESPONSE_PAYLOAD']._serialized_end=3047
  _globals['_UPSERTFEEDWITHMETA']._serialized_start=3050
  _globals['_UPSERTFEEDWITHMETA']._serialized_end=3213
  _globals['_FEEDAPI']._serialized_start=3216
  _globals['_FEEDAPI']._serialized_end=3811
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (meta)
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.rpc.status_pb2
import iotics.api.common_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SparqlResultType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SparqlResultTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SparqlResultType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SPARQL_JSON: _SparqlResultType.ValueType  # 0
    """Applicable to SELECT/ASK (SPARQL 1.1 Query Results JSON Format)"""
    SPARQL_XML: _SparqlResultType.ValueType  # 1
    """Applicable to SELECT/ASK (SPARQL 1.1 Query Results XML Format)"""
    SPARQL_CSV: _SparqlResultType.ValueType  # 2
    """Applicable to SELECT/ASK (SPARQL 1.1. Query Results CSV Format)"""
    RDF_TURTLE: _SparqlResultType.ValueType  # 3
    """Applicable to CONSTRUCT/DESCRIBE (Terse RDF Triple Language)"""
    RDF_XML: _SparqlResultType.ValueType  # 4
    """Applicable to CONSTRUCT/DESCRIBE (RDF 1.1 XML)"""
    RDF_NTRIPLES: _SparqlResultType.ValueType  # 5
    """Applicable to CONSTRUCT/DESCRIBE (RDF 1.1 N-Triples)"""

class SparqlResultType(_SparqlResultType, metaclass=_SparqlResultTypeEnumTypeWrapper):
    """SparqlResultType defines the result content types for SPARQL requests. Note that applicable content types depend on
    the type of query.
    """

SPARQL_JSON: SparqlResultType.ValueType  # 0
"""Applicable to SELECT/ASK (SPARQL 1.1 Query Results JSON Format)"""
SPARQL_XML: SparqlResultType.ValueType  # 1
"""Applicable to SELECT/ASK (SPARQL 1.1 Query Results XML Format)"""
SPARQL_CSV: SparqlResultType.ValueType  # 2
"""Applicable to SELECT/ASK (SPARQL 1.1. Query Results CSV Format)"""
RDF_TURTLE: SparqlResultType.ValueType  # 3
"""Applicable to CONSTRUCT/DESCRIBE (Terse RDF Triple Language)"""
RDF_XML: SparqlResultType.ValueType  # 4
"""Applicable to CONSTRUCT/DESCRIBE (RDF 1.1 XML)"""
RDF_NTRIPLES: SparqlResultType.ValueType  # 5
"""Applicable to CONSTRUCT/DESCRIBE (RDF 1.1 N-Triples)"""
global___SparqlResultType = SparqlResultType

@typing.final
class SparqlQueryRequest(google.protobuf.message.Message):
    """SparqlQueryRequest describes a SPARQL query."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """SPARQL query request payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESULTCONTENTTYPE_FIELD_NUMBER: builtins.int
        QUERY_FIELD_NUMBER: builtins.int
        resultContentType: global___SparqlResultType.ValueType
        """The desired result content type. Note that choosing an invalid result type for the type of query will result in
        an error status reported in the response. (See SparqlResultType for valid content-query type combinations.)
        """
        query: builtins.bytes
        """A UTF8-encoded SPARQL 1.1 query"""
        def __init__(
            self,
            *,
            resultContentType: global___SparqlResultType.ValueType = ...,
            query: builtins.bytes = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["query", b"query", "resultContentType", b"resultContentType"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    scope: iotics.api.common_pb2.Scope.ValueType
    """SPARQL query request scope"""
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """SPARQL query request headers"""

    @property
    def payload(self) -> global___SparqlQueryRequest.Payload:
        """SPARQL query request payload"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        scope: iotics.api.common_pb2.Scope.ValueType = ...,
        payload: global___SparqlQueryRequest.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload", "scope", b"scope"]) -> None: ...

global___SparqlQueryRequest = SparqlQueryRequest

@typing.final
class SparqlQueryResponse(google.protobuf.message.Message):
    """SparqlQueryResponse is a part of a result for a SPARQL query request. Multiple chunks form a complete result. Related
    chunks can be identified by a combination of:
    - Client reference (in headers, set by caller)
    - Chunk sequence number
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """Payload of the query result chunk"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SEQNUM_FIELD_NUMBER: builtins.int
        LAST_FIELD_NUMBER: builtins.int
        STATUS_FIELD_NUMBER: builtins.int
        CONTENTTYPE_FIELD_NUMBER: builtins.int
        RESULTCHUNK_FIELD_NUMBER: builtins.int
        seqNum: builtins.int
        """Position of a chunk in result for a given request. The first chunk has a sequence number of 0."""
        last: builtins.bool
        """Indicates whether this is the last chunk, for a specific request. Results for different requests can be
        identified by setting a unique clientRef in the request headers.
        """
        contentType: global___SparqlResultType.ValueType
        """Content type of the result."""
        resultChunk: builtins.bytes
        """Query result chunk, encoded according to actualType.
        Note that:
        - The maximum size of each chunk is host-specific. A typical default value is 4MiB.
        """
        @property
        def status(self) -> google.rpc.status_pb2.Status:
            """Result error status. If set, this will indicate a problem with running the query (e.g. invalid syntax or content
            type) as opposed to a more general issue (in which case the standard gRPC error mechanism will be used and the
            stream terminated).
            """

        def __init__(
            self,
            *,
            seqNum: builtins.int = ...,
            last: builtins.bool = ...,
            status: google.rpc.status_pb2.Status | None = ...,
            contentType: global___SparqlResultType.ValueType = ...,
            resultChunk: builtins.bytes = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["status", b"status"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["contentType", b"contentType", "last", b"last", "resultChunk", b"resultChunk", "seqNum", b"seqNum", "status", b"status"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """Headers for the query result. clientRef within can be used to identify which query the result applies to."""

    @property
    def payload(self) -> global___SparqlQueryResponse.Payload:
        """SPARQL query result chunk payload."""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___SparqlQueryResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___SparqlQueryResponse = SparqlQueryResponse

@typing.final
class SparqlUpdateRequest(google.protobuf.message.Message):
    """Performs a SPARQL update against custom metadata only."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        """SPARQL update request payload."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UPDATE_FIELD_NUMBER: builtins.int
        update: builtins.bytes
        """A UTF8-encoded SPARQL 1.1 update"""
        def __init__(
            self,
            *,
            update: builtins.bytes = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["update", b"update"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """SPARQL update request headers"""

    @property
    def payload(self) -> global___SparqlUpdateRequest.Payload:
        """SPARQL update request payload."""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___SparqlUpdateRequest.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___SparqlUpdateRequest = SparqlUpdateRequest

@typing.final
class SparqlUpdateResponse(google.protobuf.message.Message):
    """Response of the SPARQL update request."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADERS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers:
        """SPARQL update response headers"""

    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers"]) -> None: ...

global___SparqlUpdateResponse = SparqlUpdateResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (common)
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/host.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/host.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15iotics/api/host.proto\x12\niotics.api\x1a\x17iotics/api/common.proto\"A\n\x10GetHostIDRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\"\xa6\x01\n\x11GetHostIDResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12?\n\x07payload\x18\x02 \x01(\x0b\x32%.iotics.api.GetHostIDResponse.PayloadR\x07payload\x1a!\n\x07Payload\x12\x16\n\x06hostId\x18\x01 \x01(\tR\x06hostId\"f\n\x14HostAllowedArguments\x12\"\n\x0cremoteHostId\x18\x01 \x01(\tR\x0cremoteHostId\x12*\n\x06twinId\x18\x02 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\x86\x01\n\x1aHostAllowedResponsePayload\x12\"\n\x0cremoteHostId\x18\x01 \x01(\tR\x0cremoteHostId\x12*\n\x06twinId\x18\x02 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\x12\x18\n\x07\x61llowed\x18\x03 \x01(\x08R\x07\x61llowed\"\x7f\n\x18IsHostDataAllowedRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x34\n\x04\x61rgs\x18\x02 \x01(\x0b\x32 .iotics.api.HostAllowedArgumentsR\x04\x61rgs\"\x8c\x01\n\x19IsHostDataAllowedResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.HostAllowedResponsePayloadR\x07payload\"\x7f\n\x18IsHostMetaAllowedRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x34\n\x04\x61rgs\x18\x02 \x01(\x0b\x32 .iotics.api.HostAllowedArgumentsR\x04\x61rgs\"\x8c\x01\n\x19IsHostMetaAllowedResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.HostAllowedResponsePayloadR\x07payload2\x9d\x02\n\x07HostAPI\x12J\n\tGetHostID\x12\x1c.iotics.api.GetHostIDRequest\x1a\x1d.iotics.api.GetHostIDResponse\"\x00\x12\x62\n\x11IsHostDataAllowed\x12$.iotics.api.IsHostDataAllowedRequest\x1a%.iotics.api.IsHostDataAllowedResponse\"\x00\x12\x62\n\x11IsHostMetaAllowed\x12$.iotics.api.IsHostMetaAllowedRequest\x1a%.iotics.api.IsHostMetaAllowedResponse\"\x00\x42}\n\x0e\x63om.iotics.apiB\tHostProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.host_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\tHostProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_GETHOSTIDREQUEST']._serialized_start=62
  _globals['_GETHOSTIDREQUEST']._serialized_end=127
  _globals['_GETHOSTIDRESPONSE']._serialized_start=130
  _globals['_GETHOSTIDRESPONSE']._serialized_end=296
  _globals['_GETHOSTIDRESPONSE_PAYLOAD']._serialized_start=263
  _globals['_GETHOSTIDRESPONSE_PAYLOAD']._serialized_end=296
  _globals['_HOSTALLOWEDARGUMENTS']._serialized_start=298
  _globals['_HOSTALLOWEDARGUMENTS']._serialized_end=400
  _globals['_HOSTALLOWEDRESPONSEPAYLOAD']._serialized_start=403
  _globals['_HOSTALLOWEDRESPONSEPAYLOAD']._serialized_end=537
  _globals['_ISHOSTDATAALLOWEDREQUEST']._serialized_start=539
  _globals['_ISHOSTDATAALLOWEDREQUEST']._serialized_end=666
  _globals['_ISHOSTDATAALLOWEDRESPONSE']._serialized_start=669
  _globals['_ISHOSTDATAALLOWEDRESPONSE']._serialized_end=809
  _globals['_ISHOSTMETAALLOWEDREQUEST']._serialized_start=811
  _globals['_ISHOSTMETAALLOWEDREQUEST']._serialized_end=938
  _globals['_ISHOSTMETAALLOWEDRESPONSE']._serialized_start=941
  _globals['_ISHOSTMETAALLOWEDRESPONSE']._serialized_end=1081
  _globals['_HOSTAPI']._serialized_start=1084
  _globals['_HOSTAPI']._serialized_end=1369
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (twins)
"""

import abc
import collections.abc
import grpc
import grpc.aio
import iotics.api.twin_pb2
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TwinAPIStub:
    """---------------------------------------------------------------------------------------------------------------------

    TwinAPI enables creation and management of Iotics twins.
    Services only affect local resources, unless stated otherwise.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    CreateTwin: grpc.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.CreateTwinRequest,
        iotics.api.twin_pb2.CreateTwinResponse,
    ]
    """CreateTwin creates a twin."""

    UpsertTwin: grpc.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.UpsertTwinRequest,
        iotics.api.twin_pb2.UpsertTwinResponse,
    ]
    """UpsertTwin creates or updates a twin with its metadata + the twin feeds and inputs with their metadata.
    The full state is applied (ie. if the operation succeeds the state of the twin, feeds and inputs will be the one
    described in the payload)
    """

    DeleteTwin: grpc.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.DeleteTwinRequest,
        iotics.api.twin_pb2.DeleteTwinResponse,
    ]
    """DeleteTwin deletes a twin."""

    UpdateTwin: grpc.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.UpdateTwinRequest,
        iotics.api.twin_pb2.UpdateTwinResponse,
    ]
    """UpdateTwin updates a twin (partial update)."""

    DescribeTwin: grpc.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.DescribeTwinRequest,
        iotics.api.twin_pb2.DescribeTwinResponse,
    ]
    """Describes a twin. (local and remote)"""

    ListAllTwins: grpc.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.ListAllTwinsRequest,
        iotics.api.twin_pb2.ListAllTwinsResponse,
    ]
    """List all twins."""

class TwinAPIAsyncStub:
    """---------------------------------------------------------------------------------------------------------------------

    TwinAPI enables creation and management of Iotics twins.
    Services only affect local resources, unless stated otherwise.
    """

    CreateTwin: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.CreateTwinRequest,
        iotics.api.twin_pb2.CreateTwinResponse,
    ]
    """CreateTwin creates a twin."""

    UpsertTwin: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.UpsertTwinRequest,
        iotics.api.twin_pb2.UpsertTwinResponse,
    ]
    """UpsertTwin creates or updates a twin with its metadata + the twin feeds and inputs with their metadata.
    The full state is applied (ie. if the operation succeeds the state of the twin, feeds and inputs will be the one
    described in the payload)
    """

    DeleteTwin: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.DeleteTwinRequest,
        iotics.api.twin_pb2.DeleteTwinResponse,
    ]
    """DeleteTwin deletes a twin."""

    UpdateTwin: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.UpdateTwinRequest,
        iotics.api.twin_pb2.UpdateTwinResponse,
    ]
    """UpdateTwin updates a twin (partial update)."""

    DescribeTwin: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.DescribeTwinRequest,
        iotics.api.twin_pb2.DescribeTwinResponse,
    ]
    """Describes a twin. (local and remote)"""

    ListAllTwins: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.twin_pb2.ListAllTwinsRequest,
        iotics.api.twin_pb2.ListAllTwinsResponse,
    ]
    """List all twins."""

class TwinAPIServicer(metaclass=abc.ABCMeta):
    """---------------------------------------------------------------------------------------------------------------------

    TwinAPI enables creation and management of Iotics twins.
    Services only affect local resources, unless stated otherwise.
    """

    @abc.abstractmethod
    def CreateTwin(
        self,
        request: iotics.api.twin_pb2.CreateTwinRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.twin_pb2.CreateTwinResponse, collections.abc.Awaitable[iotics.api.twin_pb2.CreateTwinResponse]]:
        """CreateTwin creates a twin."""

    @abc.abstractmethod
    def UpsertTwin(
        self,
        request: iotics.api.twin_pb2.UpsertTwinRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.twin_pb2.UpsertTwinResponse, collections.abc.Awaitable[iotics.api.twin_pb2.UpsertTwinResponse]]:
        """UpsertTwin creates or updates a twin with its metadata + the twin feeds and inputs with their metadata.
        The full state is applied (ie. if the operation succeeds the state of the twin, feeds and inputs will be the one
        described in the payload)
        """

    @abc.abstractmethod
    def DeleteTwin(
        self,
        request: iotics.api.twin_pb2.DeleteTwinRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.twin_pb2.DeleteTwinResponse, collections.abc.Awaitable[iotics.api.twin_pb2.DeleteTwinResponse]]:
        """DeleteTwin deletes a twin."""

    @abc.abstractmethod
    def UpdateTwin(
        self,
        request: iotics.api.twin_pb2.UpdateTwinRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.twin_pb2.UpdateTwinResponse, collections.abc.Awaitable[iotics.api.twin_pb2.UpdateTwinResponse]]:
        """UpdateTwin updates a twin (partial update)."""

    @abc.abstractmethod
    def DescribeTwin(
        self,
        request: iotics.api.twin_pb2.DescribeTwinRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.twin_pb2.DescribeTwinResponse, collections.abc.Awaitable[iotics.api.twin_pb2.DescribeTwinResponse]]:
        """Describes a twin. (local and remote)"""

    @abc.abstractmethod
    def ListAllTwins(
        self,
        request: iotics.api.twin_pb2.ListAllTwinsRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.twin_pb2.ListAllTwinsResponse, collections.abc.Awaitable[iotics.api.twin_pb2.ListAllTwinsResponse]]:
        """List all twins."""

def add_TwinAPIServicer_to_server(servicer: TwinAPIServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (circles)
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import iotics.api.common_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CircleID(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Circle Identifier (using DID format)"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___CircleID = CircleID

@typing.final
class UpsertCircleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CIRCLEID_FIELD_NUMBER: builtins.int
        PROPERTIES_FIELD_NUMBER: builtins.int
        @property
        def circleId(self) -> global___CircleID: ...
        @property
        def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]: ...
        def __init__(
            self,
            *,
            circleId: global___CircleID | None = ...,
            properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["circleId", b"circleId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["circleId", b"circleId", "properties", b"properties"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def payload(self) -> global___UpsertCircleRequest.Payload: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___UpsertCircleRequest.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___UpsertCircleRequest = UpsertCircleRequest

@typing.final
class UpsertCircleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CIRCLEID_FIELD_NUMBER: builtins.int
        @property
        def circleId(self) -> global___CircleID: ...
        def __init__(
            self,
            *,
            circleId: global___CircleID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["circleId", b"circleId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["circleId", b"circleId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def payload(self) -> global___UpsertCircleResponse.Payload: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___UpsertCircleResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___UpsertCircleResponse = UpsertCircleResponse

@typing.final
class DeleteCircleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Arguments(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CIRCLEID_FIELD_NUMBER: builtins.int
        @property
        def circleId(self) -> global___CircleID: ...
        def __init__(
            self,
            *,
            circleId: global___CircleID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["circleId", b"circleId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["circleId", b"circleId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def args(self) -> global___DeleteCircleRequest.Arguments: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___DeleteCircleRequest.Arguments | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> None: ...

global___DeleteCircleRequest = DeleteCircleRequest

@typing.final
class DeleteCircleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CIRCLEID_FIELD_NUMBER: builtins.int
        @property
        def circleId(self) -> global___CircleID: ...
        def __init__(
            self,
            *,
            circleId: global___CircleID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["circleId", b"circleId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["circleId", b"circleId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def payload(self) -> global___DeleteCircleResponse.Payload: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___DeleteCircleResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___DeleteCircleResponse = DeleteCircleResponse

@typing.final
class DescribeCircleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Arguments(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CIRCLEID_FIELD_NUMBER: builtins.int
        @property
        def circleId(self) -> global___CircleID: ...
        def __init__(
            self,
            *,
            circleId: global___CircleID | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["circleId", b"circleId"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["circleId", b"circleId"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def args(self) -> global___DescribeCircleRequest.Arguments: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        args: global___DescribeCircleRequest.Arguments | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "headers", b"headers"]) -> None: ...

global___DescribeCircleRequest = DescribeCircleRequest

@typing.final
class DescribeCircleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class MetaResult(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PROPERTIES_FIELD_NUMBER: builtins.int
        UPDATEDAT_FIELD_NUMBER: builtins.int
        @property
        def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]: ...
        @property
        def updatedAt(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
            updatedAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["updatedAt", b"updatedAt"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["properties", b"properties", "updatedAt", b"updatedAt"]) -> None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CIRCLEID_FIELD_NUMBER: builtins.int
        RESULT_FIELD_NUMBER: builtins.int
        @property
        def circleId(self) -> global___CircleID: ...
        @property
        def result(self) -> global___DescribeCircleResponse.MetaResult: ...
        def __init__(
            self,
            *,
            circleId: global___CircleID | None = ...,
            result: global___DescribeCircleResponse.MetaResult | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["circleId", b"circleId", "result", b"result"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["circleId", b"circleId", "result", b"result"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def payload(self) -> global___DescribeCircleResponse.Payload: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___DescribeCircleResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___DescribeCircleResponse = DescribeCircleResponse

@typing.final
class ListAllCirclesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADERS_FIELD_NUMBER: builtins.int
    RANGE_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def range(self) -> iotics.api.common_pb2.Range: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        range: iotics.api.common_pb2.Range | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "range", b"range"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "range", b"range"]) -> None: ...

global___ListAllCirclesRequest = ListAllCirclesRequest

@typing.final
class ListAllCirclesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class CircleDetails(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CIRCLEID_FIELD_NUMBER: builtins.int
        PROPERTIES_FIELD_NUMBER: builtins.int
        UPDATEDAT_FIELD_NUMBER: builtins.int
        @property
        def circleId(self) -> global___CircleID: ...
        @property
        def properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[iotics.api.common_pb2.Property]: ...
        @property
        def updatedAt(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            circleId: global___CircleID | None = ...,
            properties: collections.abc.Iterable[iotics.api.common_pb2.Property] | None = ...,
            updatedAt: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["circleId", b"circleId", "updatedAt", b"updatedAt"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["circleId", b"circleId", "properties", b"properties", "updatedAt", b"updatedAt"]) -> None: ...

    @typing.final
    class Payload(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CIRCLES_FIELD_NUMBER: builtins.int
        @property
        def circles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListAllCirclesResponse.CircleDetails]: ...
        def __init__(
            self,
            *,
            circles: collections.abc.Iterable[global___ListAllCirclesResponse.CircleDetails] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["circles", b"circles"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> iotics.api.common_pb2.Headers: ...
    @property
    def payload(self) -> global___ListAllCirclesResponse.Payload: ...
    def __init__(
        self,
        *,
        headers: iotics.api.common_pb2.Headers | None = ...,
        payload: global___ListAllCirclesResponse.Payload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "payload", b"payload"]) -> None: ...

global___ListAllCirclesResponse = ListAllCirclesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (circles)
"""

import abc
import collections.abc
import grpc
import grpc.aio
import iotics.api.circle_pb2
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class CircleAPIStub:
    """---------------------------------------------------------------------------------------------------------------------

    CircleAPI enables creation and management of Iotics circles.
    Services only affect local resources.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    UpsertCircle: grpc.UnaryUnaryMultiCallable[
        iotics.api.circle_pb2.UpsertCircleRequest,
        iotics.api.circle_pb2.UpsertCircleResponse,
    ]
    """UpsertCircle creates or updates a circle with its metadata.
    The full state is applied (ie. if the operation succeeds the state of the circle will
    be the one described in the payload)
    """

    DeleteCircle: grpc.UnaryUnaryMultiCallable[
        iotics.api.circle_pb2.DeleteCircleRequest,
        iotics.api.circle_pb2.DeleteCircleResponse,
    ]
    """DeleteCircle deletes a circle."""

    DescribeCircle: grpc.UnaryUnaryMultiCallable[
        iotics.api.circle_pb2.DescribeCircleRequest,
        iotics.api.circle_pb2.DescribeCircleResponse,
    ]
    """Describes a circle."""

    ListAllCircles: grpc.UnaryUnaryMultiCallable[
        iotics.api.circle_pb2.ListAllCirclesRequest,
        iotics.api.circle_pb2.ListAllCirclesResponse,
    ]
    """List all circles."""

class CircleAPIAsyncStub:
    """---------------------------------------------------------------------------------------------------------------------

    CircleAPI enables creation and management of Iotics circles.
    Services only affect local resources.
    """

    UpsertCircle: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.circle_pb2.UpsertCircleRequest,
        iotics.api.circle_pb2.UpsertCircleResponse,
    ]
    """UpsertCircle creates or updates a circle with its metadata.
    The full state is applied (ie. if the operation succeeds the state of the circle will
    be the one described in the payload)
    """

    DeleteCircle: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.circle_pb2.DeleteCircleRequest,
        iotics.api.circle_pb2.DeleteCircleResponse,
    ]
    """DeleteCircle deletes a circle."""

    DescribeCircle: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.circle_pb2.DescribeCircleRequest,
        iotics.api.circle_pb2.DescribeCircleResponse,
    ]
    """Describes a circle."""

    ListAllCircles: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.circle_pb2.ListAllCirclesRequest,
        iotics.api.circle_pb2.ListAllCirclesResponse,
    ]
    """List all circles."""

class CircleAPIServicer(metaclass=abc.ABCMeta):
    """---------------------------------------------------------------------------------------------------------------------

    CircleAPI enables creation and management of Iotics circles.
    Services only affect local resources.
    """

    @abc.abstractmethod
    def UpsertCircle(
        self,
        request: iotics.api.circle_pb2.UpsertCircleRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.circle_pb2.UpsertCircleResponse, collections.abc.Awaitable[iotics.api.circle_pb2.UpsertCircleResponse]]:
        """UpsertCircle creates or updates a circle with its metadata.
        The full state is applied (ie. if the operation succeeds the state of the circle will
        be the one described in the payload)
        """

    @abc.abstractmethod
    def DeleteCircle(
        self,
        request: iotics.api.circle_pb2.DeleteCircleRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.circle_pb2.DeleteCircleResponse, collections.abc.Awaitable[iotics.api.circle_pb2.DeleteCircleResponse]]:
        """DeleteCircle deletes a circle."""

    @abc.abstractmethod
    def DescribeCircle(
        self,
        request: iotics.api.circle_pb2.DescribeCircleRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.circle_pb2.DescribeCircleResponse, collections.abc.Awaitable[iotics.api.circle_pb2.DescribeCircleResponse]]:
        """Describes a circle."""

    @abc.abstractmethod
    def ListAllCircles(
        self,
        request: iotics.api.circle_pb2.ListAllCirclesRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.circle_pb2.ListAllCirclesResponse, collections.abc.Awaitable[iotics.api.circle_pb2.ListAllCirclesResponse]]:
        """List all circles."""

def add_CircleAPIServicer_to_server(servicer: CircleAPIServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Copyright © 2022 IOTIC LABS LTD. info@iotics.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://github.com/Iotic-Labs/iotics-grpc-client-py/blob/main/LICENSE
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# For pkgutil namespace compatibility only. Must NOT contain anything else. See also:
# https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages
__path__ = __import__('pkgutil').extend_path(__path__, __name__)  # type: ignore



# Copyright © 2022 IOTIC LABS LTD. info@iotics.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://github.com/Iotic-Labs/iotics-grpc-client-py/blob/main/LICENSE
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import datetime
import uuid

import grpc
from google.protobuf.timestamp_pb2 import Timestamp

from iotics.api.common_pb2 import (
    GeoLocation,
    Headers,
    LangLiteral,
    Literal,
    Property,
    StringLiteral,
    Uri,
    Value,
)
from iotics.api.feed_pb2 import UpsertFeedWithMeta
from iotics.lib.grpc.auth import AuthInterface
from iotics.api.input_pb2 import UpsertInputWithMeta


# by default we use these options when creating a channel
# in order for the client to better know when e.g. the server is down
# https://github.com/grpc/grpc/issues/32095
# https://github.com/grpc/grpc/blob/master/doc/keepalive.md#defaults-values
KEEP_ALIVE_CHANNEL_OPTIONS = [
    # How often to PING
    ("grpc.keepalive_time_ms", 60000),
    # How long to wait for PONG response
    ("grpc.keepalive_timeout_ms", 30000),
    # When there are idle streams (e.g. followed feeds), the default of 2 will prevent
    # pings from being sent unless writes are requested. Therefore disable this option
    # and allow for pings to work regardless.
    ("grpc.http2.max_pings_without_data", 0),
]

PER_PAGE_LIMIT = 100

def get_channel(
    auth: AuthInterface, channel_options: [tuple, ...] = None
) -> grpc.Channel:
    """Creates a gRPC channel to IOTICSpace and instantiates API stub.

    Args:
        auth: Required to get a space host name and authentication token.
        channel_options: options argument passed to the grpc.secure_channel call
          by default will use KEEP_ALIVE_CHANNEL_OPTIONS

    Returns: gRPC channel.
    """

    if channel_options is None:
        channel_options = KEEP_ALIVE_CHANNEL_OPTIONS

    # note: for testing against a local server without ssl
    # you can use 'grpc.local_channel_credentials()' here instead
    channel_credentials = grpc.ssl_channel_credentials()
    call_credentials = grpc.access_token_call_credentials(auth.get_token())
    composite_credentials = grpc.composite_channel_credentials(
        channel_credentials, call_credentials
    )
    return grpc.secure_channel(
        auth.get_host(), composite_credentials, options=channel_options
    )


def create_property(key, value, language=None, datatype=None, is_uri=False):
    value = _create_property_value(value, language, datatype, is_uri)
    if isinstance(value, Uri):
        return Property(key=key, uriValue=value)
    if isinstance(value, Literal):
        return Property(key=key, literalValue=value)
    if isinstance(value, StringLiteral):
        return Property(key=key, stringLiteralValue=value)
    if isinstance(value, LangLiteral):
        return Property(key=key, langLiteralValue=value)


def _create_property_value(value, language=None, datatype=None, is_uri=False):
    if is_uri:
        return Uri(value=value)
    if language:
        return LangLiteral(value=value, lang=language)
    if datatype:
        return Literal(value=value, dataType=datatype)
    return StringLiteral(value=value)


def create_location(lat, lon):
    return GeoLocation(lat=lat, lon=lon)


def create_feed_with_meta(feed_id, store_last=True, values=None, properties=None):
    return UpsertFeedWithMeta(
        id=feed_id,
        storeLast=store_last,
        values=values,
        properties=properties
    )


def create_input_with_meta(input_id, values=None, properties=None):
    return UpsertInputWithMeta(
        id=input_id,
        values=values,
        properties=properties
    )


def create_value(label, comment=None, unit=None, data_type=None):
    return Value(label=label, comment=comment, unit=unit, dataType=data_type)


def create_headers(client_ref=None, client_app_id=None, transaction_ref=None, consumer_group=None,
                   request_timeout=None):
    client_app_id = client_app_id or uuid.uuid4().hex
    return Headers(
        clientRef=client_ref or 'IOTICS GRPC Python client',
        clientAppId=client_app_id,
        transactionRef=transaction_ref or [client_app_id],
        consumerGroup=consumer_group,
        requestTimeout=request_timeout
    )


def create_timestamp() -> Timestamp:
    """Create a Google protobuf timestamp with current time in UTC."""
    timestamp = Timestamp()
    timestamp.FromDatetime(datetime.datetime.now(datetime.timezone.utc))
    return timestamp


PROPERTY_IS_DIGITAL_TWIN = Property(
    key='http://www.w3.org/1999/02/22-rdf-syntax-ns#type',
    uriValue=Uri(value='http://data.iotics.com/iotics#DigitalTwin')
)
PROPERTY_IS_MODEL = Property(
    key='http://www.w3.org/1999/02/22-rdf-syntax-ns#type',
    uriValue=Uri(value='https://data.iotics.com/app#Model')
)
PROPERTY_CREATED_BY_MODEL = Property(
    key='http://data.iotics.com/app#CreationMeans',
    uriValue=Uri(value='http://data.iotics.com/app#ByModel')
)

# whether or not twins can be found from other spaces
METADATA_ALLOW_ALL = Property(
    key='http://data.iotics.com/public#hostMetadataAllowList',
    uriValue=Uri(value='http://data.iotics.com/public#all')
)
METADATA_ALLOW_NONE = Property(
    key='http://data.iotics.com/public#hostMetadataAllowList',
    uriValue=Uri(value='http://data.iotics.com/public#none')
)

# whether or not twins feeds can be followed from other spaces
PROPERTY_ALLOW_ALL = Property(
    key='http://data.iotics.com/public#hostAllowList',
    uriValue=Uri(value='http://data.iotics.com/public#all')
)
PROPERTY_ALLOW_NONE = Property(
    key='http://data.iotics.com/public#hostAllowList',
    uriValue=Uri(value='http://data.iotics.com/public#none')
)

PROPERTY_KEY_HAS_MODEL = 'https://data.iotics.com/app#model'
PROPERTY_KEY_COLOR = 'https://data.iotics.com/app#color'
PROPERTY_KEY_CREATED_AT = 'https://data.iotics.com/app#createdAt'
PROPERTY_KEY_CREATED_BY = 'https://data.iotics.com/app#createdBy'
PROPERTY_KEY_UPDATED_AT = 'https://data.iotics.com/app#updatedAt'
PROPERTY_KEY_UPDATED_BY = 'https://data.iotics.com/app#updatedBy'
PROPERTY_KEY_LABEL = "http://www.w3.org/2000/01/rdf-schema#label"
PROPERTY_KEY_COMMENT = "http://www.w3.org/2000/01/rdf-schema#comment"



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (c) 2019-2024 Iotic Labs Ltd. All rights reserved.

Iotics Web protocol definitions (meta)
"""

import abc
import collections.abc
import grpc
import grpc.aio
import iotics.api.meta_pb2
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class MetaAPIStub:
    """---------------------------------------------------------------------------------------------------------------------

    MetaAPI enables querying of metadata associated with Twins and Feeds.
    Services only affect local resources, unless stated otherwise.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    SparqlQuery: grpc.UnaryStreamMultiCallable[
        iotics.api.meta_pb2.SparqlQueryRequest,
        iotics.api.meta_pb2.SparqlQueryResponse,
    ]
    """SparqlQuery performs a SPARQL 1.1 query against the Federated Knowledge Graph of the Iotics network to which this
    host belongs. The result is returned as a sequence of chunks. Note that:
    - Result chunks MIGHT arrive out of order and it is the client's responsibility to re-assemble them.
    - This RPC is currently in beta, it means:
         - the logic should remain unchanged,
         - the rpc call should remain unchanged,
         - the service can be interrupted without notice.
    """

    SparqlUpdate: grpc.UnaryUnaryMultiCallable[
        iotics.api.meta_pb2.SparqlUpdateRequest,
        iotics.api.meta_pb2.SparqlUpdateResponse,
    ]
    """SparqlUpdate performs a SPARQL 1.1 update. When performing an update, the update query must contain a reference to
    one of the following graph IRIs:
    1. http://data.iotics.com/graph#custom-public (aka custom public graph) - All metadata written to this graph will be
       visible during SPARQL queries both with local & global scope (and thus, the Iotics network).
    """

class MetaAPIAsyncStub:
    """---------------------------------------------------------------------------------------------------------------------

    MetaAPI enables querying of metadata associated with Twins and Feeds.
    Services only affect local resources, unless stated otherwise.
    """

    SparqlQuery: grpc.aio.UnaryStreamMultiCallable[
        iotics.api.meta_pb2.SparqlQueryRequest,
        iotics.api.meta_pb2.SparqlQueryResponse,
    ]
    """SparqlQuery performs a SPARQL 1.1 query against the Federated Knowledge Graph of the Iotics network to which this
    host belongs. The result is returned as a sequence of chunks. Note that:
    - Result chunks MIGHT arrive out of order and it is the client's responsibility to re-assemble them.
    - This RPC is currently in beta, it means:
         - the logic should remain unchanged,
         - the rpc call should remain unchanged,
         - the service can be interrupted without notice.
    """

    SparqlUpdate: grpc.aio.UnaryUnaryMultiCallable[
        iotics.api.meta_pb2.SparqlUpdateRequest,
        iotics.api.meta_pb2.SparqlUpdateResponse,
    ]
    """SparqlUpdate performs a SPARQL 1.1 update. When performing an update, the update query must contain a reference to
    one of the following graph IRIs:
    1. http://data.iotics.com/graph#custom-public (aka custom public graph) - All metadata written to this graph will be
       visible during SPARQL queries both with local & global scope (and thus, the Iotics network).
    """

class MetaAPIServicer(metaclass=abc.ABCMeta):
    """---------------------------------------------------------------------------------------------------------------------

    MetaAPI enables querying of metadata associated with Twins and Feeds.
    Services only affect local resources, unless stated otherwise.
    """

    @abc.abstractmethod
    def SparqlQuery(
        self,
        request: iotics.api.meta_pb2.SparqlQueryRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[iotics.api.meta_pb2.SparqlQueryResponse], collections.abc.AsyncIterator[iotics.api.meta_pb2.SparqlQueryResponse]]:
        """SparqlQuery performs a SPARQL 1.1 query against the Federated Knowledge Graph of the Iotics network to which this
        host belongs. The result is returned as a sequence of chunks. Note that:
        - Result chunks MIGHT arrive out of order and it is the client's responsibility to re-assemble them.
        - This RPC is currently in beta, it means:
             - the logic should remain unchanged,
             - the rpc call should remain unchanged,
             - the service can be interrupted without notice.
        """

    @abc.abstractmethod
    def SparqlUpdate(
        self,
        request: iotics.api.meta_pb2.SparqlUpdateRequest,
        context: _ServicerContext,
    ) -> typing.Union[iotics.api.meta_pb2.SparqlUpdateResponse, collections.abc.Awaitable[iotics.api.meta_pb2.SparqlUpdateResponse]]:
        """SparqlUpdate performs a SPARQL 1.1 update. When performing an update, the update query must contain a reference to
        one of the following graph IRIs:
        1. http://data.iotics.com/graph#custom-public (aka custom public graph) - All metadata written to this graph will be
           visible during SPARQL queries both with local & global scope (and thus, the Iotics network).
        """

def add_MetaAPIServicer_to_server(servicer: MetaAPIServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Copyright © 2022 IOTIC LABS LTD. info@iotics.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://github.com/Iotic-Labs/iotics-grpc-client-py/blob/main/LICENSE
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from iotics.api.common_pb2 import Scope
from iotics.api.feed_pb2 import CreateFeedResponse, DeleteFeedResponse, DescribeFeedResponse, ListAllFeedsResponse, \
    ShareFeedDataResponse, UpdateFeedResponse
from iotics.api.interest_pb2 import FetchInterestResponse
from iotics.api.search_pb2 import SearchRequest, SearchResponse
from iotics.api.meta_pb2 import SparqlQueryResponse, SparqlResultType, SparqlUpdateResponse
from iotics.api.twin_pb2 import CreateTwinResponse, DeleteTwinResponse, DescribeTwinResponse, ListAllTwinsResponse, \
    UpdateTwinResponse, UpsertTwinResponse
from iotics.lib.grpc.iotics_api import IoticsApi
from iotics.lib.grpc.feeds import FeedApi
from iotics.lib.grpc.input import InputApi
from iotics.lib.grpc.interest import InterestApi
from iotics.lib.grpc.search import SearchApi
from iotics.lib.grpc.sparql import SparqlApi
from iotics.lib.grpc.twins import TwinApi
from iotics.lib.grpc.helpers import *

del globals()['get_channel']



# Copyright © 2022 IOTIC LABS LTD. info@iotics.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://github.com/Iotic-Labs/iotics-grpc-client-py/blob/main/LICENSE
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import typing

from iotics.api import common_pb2
from iotics.api import feed_pb2
from iotics.api import input_pb2
from iotics.api import twin_pb2
from iotics.api import twin_pb2_grpc
from .base import ApiBase
from .helpers import create_headers, PER_PAGE_LIMIT


class TwinApi(ApiBase):
    stub_class = twin_pb2_grpc.TwinAPIStub
    stub: twin_pb2_grpc.TwinAPIStub

    def create_twin(
            self,
            twin_did: str,
            headers: typing.Optional[common_pb2.Headers] = None
    ) -> twin_pb2.CreateTwinResponse:
        """Creates a twin with the given DID, which should be created using the get_did method of your chosen
        authenticator

        Args:
            twin_did: Decentralized Identifier uniquely specifying the twin
            headers: optional request headers

        Returns: Response object confirming the Twin ID
        """
        req = twin_pb2.CreateTwinRequest(
            headers=headers or create_headers(),
            payload=twin_pb2.CreateTwinRequest.Payload(id=twin_did)
        )
        return self.stub.CreateTwin(req)

    def describe_twin(
            self,
            twin_did: str,
            remote_host_id: typing.Optional[str] = None,
            headers: typing.Optional[common_pb2.Headers] = None
    ) -> twin_pb2.DescribeTwinResponse:
        """Describes the twin with the given DID, listing its location, properties, and feeds

        Args:
            twin_did: Decentralized Identifier uniquely specifying the twin
            remote_host_id: ID of the remote host on which the twin can be found (None if local)
            headers: optional request headers

        Returns: Response object describing the twin
        """

        req = twin_pb2.DescribeTwinRequest(
            headers=headers or create_headers(),
            args=twin_pb2.DescribeTwinRequest.Arguments(
                twinId=common_pb2.TwinID(id=twin_did, hostId=remote_host_id)),
        )
        return self.stub.DescribeTwin(req)

    def delete_twin(
            self,
            twin_did: str,
            headers: typing.Optional[common_pb2.Headers] = None
    ) -> twin_pb2.DeleteTwinResponse:
        """Deletes the twin with the given DID

        Args:
            twin_did: Decentralized Identifier uniquely specifying the twin
            headers: optional request headers

        Returns: Response object confirming the DID of the deleted twin
        """

        req = twin_pb2.DeleteTwinRequest(
            headers=headers or create_headers(),
            args=twin_pb2.DeleteTwinRequest.Arguments(twinId=common_pb2.TwinID(id=twin_did)))
        return self.stub.DeleteTwin(req)

    def list_twins(self, 
                   page:int = 0,
                   headers: typing.Optional[common_pb2.Headers] = None
    ) -> twin_pb2.ListAllTwinsResponse:
        """Lists all local twins visible to the user making the request

        Args:
            page: Used to request offsetted results, as responses contain only up to `PER_PAGE_LIMIT` results per request.
            headers: optional request headers

        Returns: Response object listing twins with their location and properties
        """
        
        req = twin_pb2.ListAllTwinsRequest(
            range=common_pb2.Range(
                limit=common_pb2.Limit(value=PER_PAGE_LIMIT),
                offset=common_pb2.Offset(value=PER_PAGE_LIMIT * page)
            ),
            headers=headers or create_headers())
        return self.stub.ListAllTwins(req)

    def update_twin(
            self,
            twin_did: str,
            location: typing.Optional[common_pb2.GeoLocation] = None,
            props_added: typing.Optional[list] = None,
            props_deleted: typing.Optional[list] = None,
            props_keys_deleted: typing.Optional[list] = None,
            props_clear_all: bool = False,
            headers: typing.Optional[common_pb2.Headers] = None
    ) -> twin_pb2.UpdateTwinResponse:
        """Update a twin to have the given location, and/or properties. Arguments omitted will not have
        their values updated
        Args:
            twin_did: Decentralized Identifier of the twin to update
            location: The new GeoLocation for the twin, created from lat/lon values using the create_location helper
            props_added: A list of semantic properties to be added to the twin, created using the create_property helper
            props_deleted: A list of semantic properties to be removed from the twin
            props_keys_deleted: A list of any property keys for which all values should be removed from the twin
            props_clear_all: Whether or not to clear all properties from the twin
            headers: optional request headers

        Returns: Response object confirming the ID of the twin that was updated
        """

        req = twin_pb2.UpdateTwinRequest(
            headers=headers or create_headers(),
            args=twin_pb2.UpdateTwinRequest.Arguments(twinId=common_pb2.TwinID(id=twin_did)),
            payload=twin_pb2.UpdateTwinRequest.Payload(
                location=twin_pb2.GeoLocationUpdate(location=location) if location else None,
                properties=common_pb2.PropertyUpdate(
                    added=props_added,
                    deleted=props_deleted,
                    deletedByKey=props_keys_deleted,
                    clearedAll=props_clear_all
                )
            ))
        return self.stub.UpdateTwin(req)

    def upsert_twin(
            self,
            twin_did: str,
            location: typing.Optional[common_pb2.GeoLocation] = None,
            properties: typing.Optional[typing.Iterable[common_pb2.Property]] = None,
            feeds: typing.Optional[typing.Iterable[feed_pb2.UpsertFeedWithMeta]] = None,
            inputs: typing.Optional[typing.Iterable[input_pb2.UpsertInputWithMeta]] = None,
            headers: typing.Optional[common_pb2.Headers] = None
    ) -> twin_pb2.UpsertTwinResponse:
        """Upserts a twin with the given details, ie, the given ID will specify a twin with these details regardless of
        whether a twin previously existed with this ID. Any arguments omitted will become absent or given default values

        Args:
            twin_did: Decentralized Identifier of the twin to upsert
            location: The GeoLocation for the twin, created from lat/lon values using the create_location helper
            properties: A list of semantic properties providing further information about the twin, created using the
                create_property helper
            feeds: A list of feeds on which the twin may share real-time data, created using the create_feed_with_meta
                helper
            inputs: A list of inputs on which the twin may receive messages
            headers: optional request headers

        Returns: Response object confirming the ID of the twin that was upserted
        """

        req = twin_pb2.UpsertTwinRequest(
            headers=headers or create_headers(),
            payload=twin_pb2.UpsertTwinRequest.Payload(
                twinId=common_pb2.TwinID(id=twin_did),
                location=location,
                properties=properties,
                feeds=feeds,
                inputs=inputs,
            )
        )
        return self.stub.UpsertTwin(req)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from iotics.api import input_pb2 as iotics_dot_api_dot_input__pb2


class InputAPIStub(object):
    """---------------------------------------------------------------------------------------------------------------------

    Input API groups all the actions link to a twin input.
    Services only affect local resources, unless stated otherwise.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeleteInput = channel.unary_unary(
                '/iotics.api.InputAPI/DeleteInput',
                request_serializer=iotics_dot_api_dot_input__pb2.DeleteInputRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_input__pb2.DeleteInputResponse.FromString,
                _registered_method=True)
        self.DescribeInput = channel.unary_unary(
                '/iotics.api.InputAPI/DescribeInput',
                request_serializer=iotics_dot_api_dot_input__pb2.DescribeInputRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_input__pb2.DescribeInputResponse.FromString,
                _registered_method=True)
        self.ReceiveInputMessages = channel.unary_stream(
                '/iotics.api.InputAPI/ReceiveInputMessages',
                request_serializer=iotics_dot_api_dot_input__pb2.ReceiveInputMessageRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_input__pb2.ReceiveInputMessageResponse.FromString,
                _registered_method=True)
        self.CreateInput = channel.unary_unary(
                '/iotics.api.InputAPI/CreateInput',
                request_serializer=iotics_dot_api_dot_input__pb2.CreateInputRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_input__pb2.CreateInputResponse.FromString,
                _registered_method=True)
        self.UpdateInput = channel.unary_unary(
                '/iotics.api.InputAPI/UpdateInput',
                request_serializer=iotics_dot_api_dot_input__pb2.UpdateInputRequest.SerializeToString,
                response_deserializer=iotics_dot_api_dot_input__pb2.UpdateInputResponse.FromString,
                _registered_method=True)


class InputAPIServicer(object):
    """---------------------------------------------------------------------------------------------------------------------

    Input API groups all the actions link to a twin input.
    Services only affect local resources, unless stated otherwise.
    """

    def DeleteInput(self, request, context):
        """Deletes an input. (Idempotent)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DescribeInput(self, request, context):
        """Describes an input. (local and remote)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReceiveInputMessages(self, request, context):
        """Receives input messages for a specific input.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInput(self, request, context):
        """Creates an input owned by a twin. (Idempotent)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateInput(self, request, context):
        """Updates attributes of an input, including its metadata.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InputAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DeleteInput': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteInput,
                    request_deserializer=iotics_dot_api_dot_input__pb2.DeleteInputRequest.FromString,
                    response_serializer=iotics_dot_api_dot_input__pb2.DeleteInputResponse.SerializeToString,
            ),
            'DescribeInput': grpc.unary_unary_rpc_method_handler(
                    servicer.DescribeInput,
                    request_deserializer=iotics_dot_api_dot_input__pb2.DescribeInputRequest.FromString,
                    response_serializer=iotics_dot_api_dot_input__pb2.DescribeInputResponse.SerializeToString,
            ),
            'ReceiveInputMessages': grpc.unary_stream_rpc_method_handler(
                    servicer.ReceiveInputMessages,
                    request_deserializer=iotics_dot_api_dot_input__pb2.ReceiveInputMessageRequest.FromString,
                    response_serializer=iotics_dot_api_dot_input__pb2.ReceiveInputMessageResponse.SerializeToString,
            ),
            'CreateInput': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInput,
                    request_deserializer=iotics_dot_api_dot_input__pb2.CreateInputRequest.FromString,
                    response_serializer=iotics_dot_api_dot_input__pb2.CreateInputResponse.SerializeToString,
            ),
            'UpdateInput': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateInput,
                    request_deserializer=iotics_dot_api_dot_input__pb2.UpdateInputRequest.FromString,
                    response_serializer=iotics_dot_api_dot_input__pb2.UpdateInputResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'iotics.api.InputAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('iotics.api.InputAPI', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InputAPI(object):
    """---------------------------------------------------------------------------------------------------------------------

    Input API groups all the actions link to a twin input.
    Services only affect local resources, unless stated otherwise.
    """

    @staticmethod
    def DeleteInput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.InputAPI/DeleteInput',
            iotics_dot_api_dot_input__pb2.DeleteInputRequest.SerializeToString,
            iotics_dot_api_dot_input__pb2.DeleteInputResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DescribeInput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.InputAPI/DescribeInput',
            iotics_dot_api_dot_input__pb2.DescribeInputRequest.SerializeToString,
            iotics_dot_api_dot_input__pb2.DescribeInputResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReceiveInputMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/iotics.api.InputAPI/ReceiveInputMessages',
            iotics_dot_api_dot_input__pb2.ReceiveInputMessageRequest.SerializeToString,
            iotics_dot_api_dot_input__pb2.ReceiveInputMessageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateInput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.InputAPI/CreateInput',
            iotics_dot_api_dot_input__pb2.CreateInputRequest.SerializeToString,
            iotics_dot_api_dot_input__pb2.CreateInputResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateInput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/iotics.api.InputAPI/UpdateInput',
            iotics_dot_api_dot_input__pb2.UpdateInputRequest.SerializeToString,
            iotics_dot_api_dot_input__pb2.UpdateInputResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
